weblogolib.colorscheme.ColorGroup

Package weblogolib :: Module colorscheme :: Class ColorGroup |

# Class ColorGroup

source code

    object --+
             |
            ColorGroup

    Associate a group of symbols with a color

Instance Methods
__init__(self, symbols, color, description=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, symbols, color, description=None) (Constructor) | source code
    x.__init__(...) initializes x; see x.__class__.__doc__ for signature
Overrides: object.__init__ (inherited documentation)